[−][src]Struct caminos_lib::pattern::RandomInvolution
Build a random involution on initialization, which is then kept constant.
An involution is a permutation that is a pairing/matching; if a is the destination of b then b is the destination of a.
It will panic if given an odd size.
See Randompermutation.