pub struct LinkClass {
pub delay: Time,
/* private fields */
}Expand description
Description of common properties of sets of links. For example, the links to servers could have a different delay. The topologies can set additional classes. For example, a mesh/torus can differentiate horizontal/vertical links. And a dragonfly topology can differentiate local from global links.
Fields
delay: TimeCycles the phit needs to move from one endpoint to the other endpoint.