pub struct Network {
pub topology: Box<dyn Topology>,
pub routers: Vec<Rc<RefCell<dyn Router>>>,
pub servers: Vec<Server>,
}Expand description
An instantiated network, with all its routers and servers.
Fields
topology: Box<dyn Topology>The topology defining the connectivity.
routers: Vec<Rc<RefCell<dyn Router>>>TThe collection of all the routers in the network.
servers: Vec<Server>TThe collection of all the servers in the network.